# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_datapublisher.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_datapublisher.proto',
  package='',
  syntax='proto2',
  serialized_options=_b('\220\001\001'),
  serialized_pb=_b('\n!steammessages_datapublisher.proto\x1a steammessages_unified_base.proto\"\xfd\x03\n9CDataPublisher_ClientContentCorruptionReport_Notification\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0f\n\x07\x64\x65potid\x18\x02 \x01(\r\x12\x39\n\x0f\x64ownload_source\x18\x03 \x01(\tB \x82\xb5\x18\x1chost name of download source\x12.\n\x08objectid\x18\x04 \x01(\tB\x1c\x82\xb5\x18\x18\x43hunk SHA or Manifest ID\x12\"\n\x06\x63\x65llid\x18\x05 \x01(\rB\x12\x82\xb5\x18\x0e\x43lient Cell ID\x12>\n\x0bis_manifest\x18\x06 \x01(\x08\x42)\x82\xb5\x18%The object is a manifest, not a chunk\x12-\n\x0bobject_size\x18\x07 \x01(\x04\x42\x18\x82\xb5\x18\x14object size in bytes\x12\x37\n\x0f\x63orruption_type\x18\x08 \x01(\rB\x1e\x82\xb5\x18\x1aSee EContentCorruptionType\x12-\n\nused_https\x18\t \x01(\x08\x42\x19\x82\xb5\x18\x15the request was HTTPS\x12:\n\x11oc_proxy_detected\x18\n \x01(\x08\x42\x1f\x82\xb5\x18\x1b\x64\x65tected an OpenCache proxy\"c\n(CValveHWSurvey_GetSurveySchedule_Request\x12\x17\n\x0fsurveydatetoken\x18\x01 \x01(\t\x12\x1e\n\x16surveydatetokenversion\x18\x02 \x01(\x06\"d\n)CValveHWSurvey_GetSurveySchedule_Response\x12\x17\n\x0fsurveydatetoken\x18\x01 \x01(\r\x12\x1e\n\x16surveydatetokenversion\x18\x02 \x01(\x06\x32\xa2\x01\n\rDataPublisher\x12h\n\x1d\x43lientContentCorruptionReport\x12:.CDataPublisher_ClientContentCorruptionReport_Notification\x1a\x0b.NoResponse\x1a\'\x82\xb5\x18#Data Publisher (DP) server services2\xac\x01\n\rValveHWSurvey\x12\x87\x01\n\x11GetSurveySchedule\x12).CValveHWSurvey_GetSurveySchedule_Request\x1a*.CValveHWSurvey_GetSurveySchedule_Response\"\x1b\x82\xb5\x18\x17Should I run the survey\x1a\x11\x82\xb5\x18\rValveHWSurveyB\x03\x90\x01\x01')
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,])




_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION = _descriptor.Descriptor(
  name='CDataPublisher_ClientContentCorruptionReport_Notification',
  full_name='CDataPublisher_ClientContentCorruptionReport_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='depotid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.depotid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='download_source', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.download_source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\034host name of download source'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.objectid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\030Chunk SHA or Manifest ID'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cellid', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.cellid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\016Client Cell ID'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_manifest', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.is_manifest', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030%The object is a manifest, not a chunk'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_size', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.object_size', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\024object size in bytes'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='corruption_type', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.corruption_type', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\032See EContentCorruptionType'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='used_https', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.used_https', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\025the request was HTTPS'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oc_proxy_detected', full_name='CDataPublisher_ClientContentCorruptionReport_Notification.oc_proxy_detected', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\033detected an OpenCache proxy'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=581,
)


_CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST = _descriptor.Descriptor(
  name='CValveHWSurvey_GetSurveySchedule_Request',
  full_name='CValveHWSurvey_GetSurveySchedule_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='surveydatetoken', full_name='CValveHWSurvey_GetSurveySchedule_Request.surveydatetoken', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='surveydatetokenversion', full_name='CValveHWSurvey_GetSurveySchedule_Request.surveydatetokenversion', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=682,
)


_CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE = _descriptor.Descriptor(
  name='CValveHWSurvey_GetSurveySchedule_Response',
  full_name='CValveHWSurvey_GetSurveySchedule_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='surveydatetoken', full_name='CValveHWSurvey_GetSurveySchedule_Response.surveydatetoken', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='surveydatetokenversion', full_name='CValveHWSurvey_GetSurveySchedule_Response.surveydatetokenversion', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=684,
  serialized_end=784,
)

DESCRIPTOR.message_types_by_name['CDataPublisher_ClientContentCorruptionReport_Notification'] = _CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CValveHWSurvey_GetSurveySchedule_Request'] = _CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST
DESCRIPTOR.message_types_by_name['CValveHWSurvey_GetSurveySchedule_Response'] = _CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CDataPublisher_ClientContentCorruptionReport_Notification = _reflection.GeneratedProtocolMessageType('CDataPublisher_ClientContentCorruptionReport_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION,
  __module__ = 'steammessages_datapublisher_pb2'
  # @@protoc_insertion_point(class_scope:CDataPublisher_ClientContentCorruptionReport_Notification)
  ))
_sym_db.RegisterMessage(CDataPublisher_ClientContentCorruptionReport_Notification)

CValveHWSurvey_GetSurveySchedule_Request = _reflection.GeneratedProtocolMessageType('CValveHWSurvey_GetSurveySchedule_Request', (_message.Message,), dict(
  DESCRIPTOR = _CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST,
  __module__ = 'steammessages_datapublisher_pb2'
  # @@protoc_insertion_point(class_scope:CValveHWSurvey_GetSurveySchedule_Request)
  ))
_sym_db.RegisterMessage(CValveHWSurvey_GetSurveySchedule_Request)

CValveHWSurvey_GetSurveySchedule_Response = _reflection.GeneratedProtocolMessageType('CValveHWSurvey_GetSurveySchedule_Response', (_message.Message,), dict(
  DESCRIPTOR = _CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE,
  __module__ = 'steammessages_datapublisher_pb2'
  # @@protoc_insertion_point(class_scope:CValveHWSurvey_GetSurveySchedule_Response)
  ))
_sym_db.RegisterMessage(CValveHWSurvey_GetSurveySchedule_Response)


DESCRIPTOR._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['download_source']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['objectid']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['cellid']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['is_manifest']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['object_size']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['corruption_type']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['used_https']._options = None
_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION.fields_by_name['oc_proxy_detected']._options = None

_DATAPUBLISHER = _descriptor.ServiceDescriptor(
  name='DataPublisher',
  full_name='DataPublisher',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\202\265\030#Data Publisher (DP) server services'),
  serialized_start=787,
  serialized_end=949,
  methods=[
  _descriptor.MethodDescriptor(
    name='ClientContentCorruptionReport',
    full_name='DataPublisher.ClientContentCorruptionReport',
    index=0,
    containing_service=None,
    input_type=_CDATAPUBLISHER_CLIENTCONTENTCORRUPTIONREPORT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPUBLISHER)

DESCRIPTOR.services_by_name['DataPublisher'] = _DATAPUBLISHER


_VALVEHWSURVEY = _descriptor.ServiceDescriptor(
  name='ValveHWSurvey',
  full_name='ValveHWSurvey',
  file=DESCRIPTOR,
  index=1,
  serialized_options=_b('\202\265\030\rValveHWSurvey'),
  serialized_start=952,
  serialized_end=1124,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSurveySchedule',
    full_name='ValveHWSurvey.GetSurveySchedule',
    index=0,
    containing_service=None,
    input_type=_CVALVEHWSURVEY_GETSURVEYSCHEDULE_REQUEST,
    output_type=_CVALVEHWSURVEY_GETSURVEYSCHEDULE_RESPONSE,
    serialized_options=_b('\202\265\030\027Should I run the survey'),
  ),
])
_sym_db.RegisterServiceDescriptor(_VALVEHWSURVEY)

DESCRIPTOR.services_by_name['ValveHWSurvey'] = _VALVEHWSURVEY

DataPublisher = service_reflection.GeneratedServiceType('DataPublisher', (_service.Service,), dict(
  DESCRIPTOR = _DATAPUBLISHER,
  __module__ = 'steammessages_datapublisher_pb2'
  ))

DataPublisher_Stub = service_reflection.GeneratedServiceStubType('DataPublisher_Stub', (DataPublisher,), dict(
  DESCRIPTOR = _DATAPUBLISHER,
  __module__ = 'steammessages_datapublisher_pb2'
  ))


ValveHWSurvey = service_reflection.GeneratedServiceType('ValveHWSurvey', (_service.Service,), dict(
  DESCRIPTOR = _VALVEHWSURVEY,
  __module__ = 'steammessages_datapublisher_pb2'
  ))

ValveHWSurvey_Stub = service_reflection.GeneratedServiceStubType('ValveHWSurvey_Stub', (ValveHWSurvey,), dict(
  DESCRIPTOR = _VALVEHWSURVEY,
  __module__ = 'steammessages_datapublisher_pb2'
  ))


# @@protoc_insertion_point(module_scope)




from steam.enums import EResult

class SteamError(Exception):
    def __init__(self, message, eresult=EResult.Fail):
        Exception.__init__(self, message, eresult)
        self.message = message
        self.eresult = EResult(eresult)  #: :class:`.EResult`

    def __str__(self):
        return "(%s) %s" % (self.eresult, self.message)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_econ.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_econ.proto',
  package='',
  syntax='proto2',
  serialized_options=_b('\220\001\001'),
  serialized_pb=_b('\n\x18steammessages_econ.proto\x1a steammessages_unified_base.proto\"D\n&CEcon_GetTradeOfferAccessToken_Request\x12\x1a\n\x12generate_new_token\x18\x01 \x01(\x08\"K\n\'CEcon_GetTradeOfferAccessToken_Response\x12 \n\x18trade_offer_access_token\x18\x01 \x01(\t\"C\n-CEcon_ClientGetItemShopOverlayAuthURL_Request\x12\x12\n\nreturn_url\x18\x01 \x01(\t\"=\n.CEcon_ClientGetItemShopOverlayAuthURL_Response\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xa9\x01\n\x1f\x43\x45\x63on_GetAssetClassInfo_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x37\n\x07\x63lasses\x18\x03 \x03(\x0b\x32&.CEcon_GetAssetClassInfo_Request.Class\x1a,\n\x05\x43lass\x12\x0f\n\x07\x63lassid\x18\x01 \x01(\x04\x12\x12\n\ninstanceid\x18\x02 \x01(\x04\"V\n\x19\x43\x45\x63onItem_DescriptionLine\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05\x63olor\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\".\n\x10\x43\x45\x63onItem_Action\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xe3\x06\n\x15\x43\x45\x63onItem_Description\x12\r\n\x05\x61ppid\x18\x01 \x01(\x05\x12\x0f\n\x07\x63lassid\x18\x02 \x01(\x04\x12\x12\n\ninstanceid\x18\x03 \x01(\x04\x12\x10\n\x08\x63urrency\x18\x04 \x01(\x08\x12\x18\n\x10\x62\x61\x63kground_color\x18\x05 \x01(\t\x12\x10\n\x08icon_url\x18\x06 \x01(\t\x12\x16\n\x0eicon_url_large\x18\x07 \x01(\t\x12\x30\n\x0c\x64\x65scriptions\x18\x08 \x03(\x0b\x32\x1a.CEconItem_DescriptionLine\x12\x10\n\x08tradable\x18\t \x01(\x08\x12\"\n\x07\x61\x63tions\x18\n \x03(\x0b\x32\x11.CEconItem_Action\x12\x36\n\x12owner_descriptions\x18\x0b \x03(\x0b\x32\x1a.CEconItem_DescriptionLine\x12(\n\rowner_actions\x18\x0c \x03(\x0b\x32\x11.CEconItem_Action\x12\x15\n\rfraudwarnings\x18\r \x03(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x12\n\nname_color\x18\x0f \x01(\t\x12\x0c\n\x04type\x18\x10 \x01(\t\x12\x13\n\x0bmarket_name\x18\x11 \x01(\t\x12\x18\n\x10market_hash_name\x18\x12 \x01(\t\x12\x12\n\nmarket_fee\x18\x13 \x01(\t\x12\x16\n\x0emarket_fee_app\x18\x1c \x01(\x05\x12.\n\x0e\x63ontained_item\x18\x14 \x01(\x0b\x32\x16.CEconItem_Description\x12)\n\x0emarket_actions\x18\x15 \x03(\x0b\x32\x11.CEconItem_Action\x12\x11\n\tcommodity\x18\x16 \x01(\x08\x12#\n\x1bmarket_tradable_restriction\x18\x17 \x01(\x05\x12%\n\x1dmarket_marketable_restriction\x18\x18 \x01(\x05\x12\x12\n\nmarketable\x18\x19 \x01(\x08\x12\x1c\n\x04tags\x18\x1a \x03(\x0b\x32\x0e.CEconItem_Tag\x12\x17\n\x0fitem_expiration\x18\x1b \x01(\t\x12&\n\x1emarket_buy_country_restriction\x18\x1e \x01(\t\x12\'\n\x1fmarket_sell_country_restriction\x18\x1f \x01(\t\"\x98\x03\n\rCEconItem_Tag\x12\x31\n\x05\x61ppid\x18\x01 \x01(\rB\"\x82\xb5\x18\x1eThe app that contains the item\x12J\n\x08\x63\x61tegory\x18\x02 \x01(\tB8\x82\xb5\x18\x34The internal name of the category the tag belongs to\x12\x37\n\rinternal_name\x18\x03 \x01(\tB \x82\xb5\x18\x1cThe internal name of the tag\x12G\n\x17localized_category_name\x18\x04 \x01(\tB&\x82\xb5\x18\"The localized name of the category\x12=\n\x12localized_tag_name\x18\x05 \x01(\tB!\x82\xb5\x18\x1dThe localized name of the tag\x12G\n\x05\x63olor\x18\x06 \x01(\tB8\x82\xb5\x18\x34The color to use when displaying the tag to the user\"P\n CEcon_GetAssetClassInfo_Response\x12,\n\x0c\x64\x65scriptions\x18\x01 \x03(\x0b\x32\x16.CEconItem_Description2\xe2\x04\n\x04\x45\x63on\x12\x9a\x01\n\x18GetTradeOfferAccessToken\x12\'.CEcon_GetTradeOfferAccessToken_Request\x1a(.CEcon_GetTradeOfferAccessToken_Response\"+\x82\xb5\x18\'Get the user\'s trade offer access token\x12\xd9\x01\n\x1f\x43lientGetItemShopOverlayAuthURL\x12..CEcon_ClientGetItemShopOverlayAuthURL_Request\x1a/.CEcon_ClientGetItemShopOverlayAuthURL_Response\"U\x82\xb5\x18QGenerates a URL which sets a secure cookie for in-game-browser itemshop purchases\x12\x9f\x01\n\x11GetAssetClassInfo\x12 .CEcon_GetAssetClassInfo_Request\x1a!.CEcon_GetAssetClassInfo_Response\"E\x82\xb5\x18\x41Returns description information about the passed in asset classes\x1a?\x82\xb5\x18;A service that provides communication with the econ serversB\x03\x90\x01\x01')
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,])




_CECON_GETTRADEOFFERACCESSTOKEN_REQUEST = _descriptor.Descriptor(
  name='CEcon_GetTradeOfferAccessToken_Request',
  full_name='CEcon_GetTradeOfferAccessToken_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='generate_new_token', full_name='CEcon_GetTradeOfferAccessToken_Request.generate_new_token', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=130,
)


_CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE = _descriptor.Descriptor(
  name='CEcon_GetTradeOfferAccessToken_Response',
  full_name='CEcon_GetTradeOfferAccessToken_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_offer_access_token', full_name='CEcon_GetTradeOfferAccessToken_Response.trade_offer_access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=207,
)


_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST = _descriptor.Descriptor(
  name='CEcon_ClientGetItemShopOverlayAuthURL_Request',
  full_name='CEcon_ClientGetItemShopOverlayAuthURL_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='return_url', full_name='CEcon_ClientGetItemShopOverlayAuthURL_Request.return_url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=276,
)


_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE = _descriptor.Descriptor(
  name='CEcon_ClientGetItemShopOverlayAuthURL_Response',
  full_name='CEcon_ClientGetItemShopOverlayAuthURL_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='CEcon_ClientGetItemShopOverlayAuthURL_Response.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=339,
)


_CECON_GETASSETCLASSINFO_REQUEST_CLASS = _descriptor.Descriptor(
  name='Class',
  full_name='CEcon_GetAssetClassInfo_Request.Class',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='classid', full_name='CEcon_GetAssetClassInfo_Request.Class.classid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CEcon_GetAssetClassInfo_Request.Class.instanceid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=511,
)

_CECON_GETASSETCLASSINFO_REQUEST = _descriptor.Descriptor(
  name='CEcon_GetAssetClassInfo_Request',
  full_name='CEcon_GetAssetClassInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CEcon_GetAssetClassInfo_Request.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEcon_GetAssetClassInfo_Request.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classes', full_name='CEcon_GetAssetClassInfo_Request.classes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CECON_GETASSETCLASSINFO_REQUEST_CLASS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=511,
)


_CECONITEM_DESCRIPTIONLINE = _descriptor.Descriptor(
  name='CEconItem_DescriptionLine',
  full_name='CEconItem_DescriptionLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CEconItem_DescriptionLine.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='CEconItem_DescriptionLine.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='CEconItem_DescriptionLine.color', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='CEconItem_DescriptionLine.label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=599,
)


_CECONITEM_ACTION = _descriptor.Descriptor(
  name='CEconItem_Action',
  full_name='CEconItem_Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='link', full_name='CEconItem_Action.link', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CEconItem_Action.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=647,
)


_CECONITEM_DESCRIPTION = _descriptor.Descriptor(
  name='CEconItem_Description',
  full_name='CEconItem_Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEconItem_Description.appid', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classid', full_name='CEconItem_Description.classid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instanceid', full_name='CEconItem_Description.instanceid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency', full_name='CEconItem_Description.currency', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='background_color', full_name='CEconItem_Description.background_color', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='icon_url', full_name='CEconItem_Description.icon_url', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='icon_url_large', full_name='CEconItem_Description.icon_url_large', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='CEconItem_Description.descriptions', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tradable', full_name='CEconItem_Description.tradable', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='actions', full_name='CEconItem_Description.actions', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_descriptions', full_name='CEconItem_Description.owner_descriptions', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_actions', full_name='CEconItem_Description.owner_actions', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fraudwarnings', full_name='CEconItem_Description.fraudwarnings', index=12,
      number=13, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CEconItem_Description.name', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name_color', full_name='CEconItem_Description.name_color', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='CEconItem_Description.type', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_name', full_name='CEconItem_Description.market_name', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_hash_name', full_name='CEconItem_Description.market_hash_name', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_fee', full_name='CEconItem_Description.market_fee', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_fee_app', full_name='CEconItem_Description.market_fee_app', index=19,
      number=28, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contained_item', full_name='CEconItem_Description.contained_item', index=20,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_actions', full_name='CEconItem_Description.market_actions', index=21,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commodity', full_name='CEconItem_Description.commodity', index=22,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_tradable_restriction', full_name='CEconItem_Description.market_tradable_restriction', index=23,
      number=23, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_marketable_restriction', full_name='CEconItem_Description.market_marketable_restriction', index=24,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketable', full_name='CEconItem_Description.marketable', index=25,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CEconItem_Description.tags', index=26,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='item_expiration', full_name='CEconItem_Description.item_expiration', index=27,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_buy_country_restriction', full_name='CEconItem_Description.market_buy_country_restriction', index=28,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market_sell_country_restriction', full_name='CEconItem_Description.market_sell_country_restriction', index=29,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=1517,
)


_CECONITEM_TAG = _descriptor.Descriptor(
  name='CEconItem_Tag',
  full_name='CEconItem_Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CEconItem_Tag.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\036The app that contains the item'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='CEconItem_Tag.category', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\0304The internal name of the category the tag belongs to'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_name', full_name='CEconItem_Tag.internal_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\034The internal name of the tag'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localized_category_name', full_name='CEconItem_Tag.localized_category_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\"The localized name of the category'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localized_tag_name', full_name='CEconItem_Tag.localized_tag_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\030\035The localized name of the tag'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='CEconItem_Tag.color', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\202\265\0304The color to use when displaying the tag to the user'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1520,
  serialized_end=1928,
)


_CECON_GETASSETCLASSINFO_RESPONSE = _descriptor.Descriptor(
  name='CEcon_GetAssetClassInfo_Response',
  full_name='CEcon_GetAssetClassInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='descriptions', full_name='CEcon_GetAssetClassInfo_Response.descriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1930,
  serialized_end=2010,
)

_CECON_GETASSETCLASSINFO_REQUEST_CLASS.containing_type = _CECON_GETASSETCLASSINFO_REQUEST
_CECON_GETASSETCLASSINFO_REQUEST.fields_by_name['classes'].message_type = _CECON_GETASSETCLASSINFO_REQUEST_CLASS
_CECONITEM_DESCRIPTION.fields_by_name['descriptions'].message_type = _CECONITEM_DESCRIPTIONLINE
_CECONITEM_DESCRIPTION.fields_by_name['actions'].message_type = _CECONITEM_ACTION
_CECONITEM_DESCRIPTION.fields_by_name['owner_descriptions'].message_type = _CECONITEM_DESCRIPTIONLINE
_CECONITEM_DESCRIPTION.fields_by_name['owner_actions'].message_type = _CECONITEM_ACTION
_CECONITEM_DESCRIPTION.fields_by_name['contained_item'].message_type = _CECONITEM_DESCRIPTION
_CECONITEM_DESCRIPTION.fields_by_name['market_actions'].message_type = _CECONITEM_ACTION
_CECONITEM_DESCRIPTION.fields_by_name['tags'].message_type = _CECONITEM_TAG
_CECON_GETASSETCLASSINFO_RESPONSE.fields_by_name['descriptions'].message_type = _CECONITEM_DESCRIPTION
DESCRIPTOR.message_types_by_name['CEcon_GetTradeOfferAccessToken_Request'] = _CECON_GETTRADEOFFERACCESSTOKEN_REQUEST
DESCRIPTOR.message_types_by_name['CEcon_GetTradeOfferAccessToken_Response'] = _CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE
DESCRIPTOR.message_types_by_name['CEcon_ClientGetItemShopOverlayAuthURL_Request'] = _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST
DESCRIPTOR.message_types_by_name['CEcon_ClientGetItemShopOverlayAuthURL_Response'] = _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE
DESCRIPTOR.message_types_by_name['CEcon_GetAssetClassInfo_Request'] = _CECON_GETASSETCLASSINFO_REQUEST
DESCRIPTOR.message_types_by_name['CEconItem_DescriptionLine'] = _CECONITEM_DESCRIPTIONLINE
DESCRIPTOR.message_types_by_name['CEconItem_Action'] = _CECONITEM_ACTION
DESCRIPTOR.message_types_by_name['CEconItem_Description'] = _CECONITEM_DESCRIPTION
DESCRIPTOR.message_types_by_name['CEconItem_Tag'] = _CECONITEM_TAG
DESCRIPTOR.message_types_by_name['CEcon_GetAssetClassInfo_Response'] = _CECON_GETASSETCLASSINFO_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CEcon_GetTradeOfferAccessToken_Request = _reflection.GeneratedProtocolMessageType('CEcon_GetTradeOfferAccessToken_Request', (_message.Message,), dict(
  DESCRIPTOR = _CECON_GETTRADEOFFERACCESSTOKEN_REQUEST,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetTradeOfferAccessToken_Request)
  ))
_sym_db.RegisterMessage(CEcon_GetTradeOfferAccessToken_Request)

CEcon_GetTradeOfferAccessToken_Response = _reflection.GeneratedProtocolMessageType('CEcon_GetTradeOfferAccessToken_Response', (_message.Message,), dict(
  DESCRIPTOR = _CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetTradeOfferAccessToken_Response)
  ))
_sym_db.RegisterMessage(CEcon_GetTradeOfferAccessToken_Response)

CEcon_ClientGetItemShopOverlayAuthURL_Request = _reflection.GeneratedProtocolMessageType('CEcon_ClientGetItemShopOverlayAuthURL_Request', (_message.Message,), dict(
  DESCRIPTOR = _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_ClientGetItemShopOverlayAuthURL_Request)
  ))
_sym_db.RegisterMessage(CEcon_ClientGetItemShopOverlayAuthURL_Request)

CEcon_ClientGetItemShopOverlayAuthURL_Response = _reflection.GeneratedProtocolMessageType('CEcon_ClientGetItemShopOverlayAuthURL_Response', (_message.Message,), dict(
  DESCRIPTOR = _CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_ClientGetItemShopOverlayAuthURL_Response)
  ))
_sym_db.RegisterMessage(CEcon_ClientGetItemShopOverlayAuthURL_Response)

CEcon_GetAssetClassInfo_Request = _reflection.GeneratedProtocolMessageType('CEcon_GetAssetClassInfo_Request', (_message.Message,), dict(

  Class = _reflection.GeneratedProtocolMessageType('Class', (_message.Message,), dict(
    DESCRIPTOR = _CECON_GETASSETCLASSINFO_REQUEST_CLASS,
    __module__ = 'steammessages_econ_pb2'
    # @@protoc_insertion_point(class_scope:CEcon_GetAssetClassInfo_Request.Class)
    ))
  ,
  DESCRIPTOR = _CECON_GETASSETCLASSINFO_REQUEST,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetAssetClassInfo_Request)
  ))
_sym_db.RegisterMessage(CEcon_GetAssetClassInfo_Request)
_sym_db.RegisterMessage(CEcon_GetAssetClassInfo_Request.Class)

CEconItem_DescriptionLine = _reflection.GeneratedProtocolMessageType('CEconItem_DescriptionLine', (_message.Message,), dict(
  DESCRIPTOR = _CECONITEM_DESCRIPTIONLINE,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_DescriptionLine)
  ))
_sym_db.RegisterMessage(CEconItem_DescriptionLine)

CEconItem_Action = _reflection.GeneratedProtocolMessageType('CEconItem_Action', (_message.Message,), dict(
  DESCRIPTOR = _CECONITEM_ACTION,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_Action)
  ))
_sym_db.RegisterMessage(CEconItem_Action)

CEconItem_Description = _reflection.GeneratedProtocolMessageType('CEconItem_Description', (_message.Message,), dict(
  DESCRIPTOR = _CECONITEM_DESCRIPTION,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_Description)
  ))
_sym_db.RegisterMessage(CEconItem_Description)

CEconItem_Tag = _reflection.GeneratedProtocolMessageType('CEconItem_Tag', (_message.Message,), dict(
  DESCRIPTOR = _CECONITEM_TAG,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEconItem_Tag)
  ))
_sym_db.RegisterMessage(CEconItem_Tag)

CEcon_GetAssetClassInfo_Response = _reflection.GeneratedProtocolMessageType('CEcon_GetAssetClassInfo_Response', (_message.Message,), dict(
  DESCRIPTOR = _CECON_GETASSETCLASSINFO_RESPONSE,
  __module__ = 'steammessages_econ_pb2'
  # @@protoc_insertion_point(class_scope:CEcon_GetAssetClassInfo_Response)
  ))
_sym_db.RegisterMessage(CEcon_GetAssetClassInfo_Response)


DESCRIPTOR._options = None
_CECONITEM_TAG.fields_by_name['appid']._options = None
_CECONITEM_TAG.fields_by_name['category']._options = None
_CECONITEM_TAG.fields_by_name['internal_name']._options = None
_CECONITEM_TAG.fields_by_name['localized_category_name']._options = None
_CECONITEM_TAG.fields_by_name['localized_tag_name']._options = None
_CECONITEM_TAG.fields_by_name['color']._options = None

_ECON = _descriptor.ServiceDescriptor(
  name='Econ',
  full_name='Econ',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\202\265\030;A service that provides communication with the econ servers'),
  serialized_start=2013,
  serialized_end=2623,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetTradeOfferAccessToken',
    full_name='Econ.GetTradeOfferAccessToken',
    index=0,
    containing_service=None,
    input_type=_CECON_GETTRADEOFFERACCESSTOKEN_REQUEST,
    output_type=_CECON_GETTRADEOFFERACCESSTOKEN_RESPONSE,
    serialized_options=_b('\202\265\030\'Get the user\'s trade offer access token'),
  ),
  _descriptor.MethodDescriptor(
    name='ClientGetItemShopOverlayAuthURL',
    full_name='Econ.ClientGetItemShopOverlayAuthURL',
    index=1,
    containing_service=None,
    input_type=_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_REQUEST,
    output_type=_CECON_CLIENTGETITEMSHOPOVERLAYAUTHURL_RESPONSE,
    serialized_options=_b('\202\265\030QGenerates a URL which sets a secure cookie for in-game-browser itemshop purchases'),
  ),
  _descriptor.MethodDescriptor(
    name='GetAssetClassInfo',
    full_name='Econ.GetAssetClassInfo',
    index=2,
    containing_service=None,
    input_type=_CECON_GETASSETCLASSINFO_REQUEST,
    output_type=_CECON_GETASSETCLASSINFO_RESPONSE,
    serialized_options=_b('\202\265\030AReturns description information about the passed in asset classes'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ECON)

DESCRIPTOR.services_by_name['Econ'] = _ECON

Econ = service_reflection.GeneratedServiceType('Econ', (_service.Service,), dict(
  DESCRIPTOR = _ECON,
  __module__ = 'steammessages_econ_pb2'
  ))

Econ_Stub = service_reflection.GeneratedServiceStubType('Econ_Stub', (Econ,), dict(
  DESCRIPTOR = _ECON,
  __module__ = 'steammessages_econ_pb2'
  ))


# @@protoc_insertion_point(module_scope)



import re
from importlib import import_module

service_lookup = {
    'Broadcast':                 'steam.protobufs.steammessages_broadcast_pb2',
    'BroadcastClient':           'steam.protobufs.steammessages_broadcast_pb2',
    'Chat':                      'steam.protobufs.steammessages_chat_pb2',
    'ChatRoom':                  'steam.protobufs.steammessages_chat_pb2',
    'ChatRoomClient':            'steam.protobufs.steammessages_chat_pb2',
    'ChatUsability':             'steam.protobufs.steammessages_chat_pb2',
    'ChatUsabilityClient':       'steam.protobufs.steammessages_chat_pb2',
    'ClanChatRooms':             'steam.protobufs.steammessages_chat_pb2',
    'Cloud':                     'steam.protobufs.steammessages_cloud_pb2',
    'Credentials':               'steam.protobufs.steammessages_credentials_pb2',
    'DataPublisher':             'steam.protobufs.steammessages_datapublisher_pb2',
    'ValveHWSurvey':             'steam.protobufs.steammessages_datapublisher_pb2',
    'ContentBuilder':            'steam.protobufs.steammessages_depotbuilder_pb2',
    'DeviceAuth':                'steam.protobufs.steammessages_deviceauth_pb2',
    'Econ':                      'steam.protobufs.steammessages_econ_pb2',
    'FriendMessages':            'steam.protobufs.steammessages_friendmessages_pb2',
    'FriendMessagesClient':      'steam.protobufs.steammessages_friendmessages_pb2',
    'GameNotifications':         'steam.protobufs.steammessages_gamenotifications_pb2',
    'GameNotificationsClient':   'steam.protobufs.steammessages_gamenotifications_pb2',
    'GameServers':               'steam.protobufs.steammessages_gameservers_pb2',
    'Inventory':                 'steam.protobufs.steammessages_inventory_pb2',
    'InventoryClient':           'steam.protobufs.steammessages_inventory_pb2',
    'CommunityLinkFilter':       'steam.protobufs.steammessages_linkfilter_pb2',
    'Offline':                   'steam.protobufs.steammessages_offline_pb2',
    'Parental':                  'steam.protobufs.steammessages_parental_pb2',
    'PartnerApps':               'steam.protobufs.steammessages_partnerapps_pb2',
    'PhysicalGoods':             'steam.protobufs.steammessages_physicalgoods_pb2',
    'Player':                    'steam.protobufs.steammessages_player_pb2',
    'PlayerClient':              'steam.protobufs.steammessages_player_pb2',
    'PublishedFile':             'steam.protobufs.steammessages_publishedfile_pb2',
    'PublishedFileClient':       'steam.protobufs.steammessages_publishedfile_pb2',
    'Secrets':                   'steam.protobufs.steammessages_secrets_pb2',
    'Shader':                    'steam.protobufs.steammessages_shader_pb2',
    'SiteLicense':               'steam.protobufs.steammessages_site_license_pb2',
    'SiteManagerClient':         'steam.protobufs.steammessages_site_license_pb2',
    'Store':                     'steam.protobufs.steammessages_store_pb2',
    'StoreClient':               'steam.protobufs.steammessages_store_pb2',
    'TwoFactor':                 'steam.protobufs.steammessages_twofactor_pb2',
    'AccountLinking':            'steam.protobufs.steammessages_useraccount_pb2',
    'EmbeddedClient':            'steam.protobufs.steammessages_useraccount_pb2',
    'UserAccount':               'steam.protobufs.steammessages_useraccount_pb2',
    'FovasVideo':                'steam.protobufs.steammessages_video_pb2',
    'Video':                     'steam.protobufs.steammessages_video_pb2',
    'VideoClient':               'steam.protobufs.steammessages_video_pb2',
    'Clan':                      'steam.protobufs.steammessages_webui_friends_pb2',
    'Community':                 'steam.protobufs.steammessages_webui_friends_pb2',
    'ExperimentService':         'steam.protobufs.steammessages_webui_friends_pb2',
    'FriendsList':               'steam.protobufs.steammessages_webui_friends_pb2',
    'FriendsListClient':         'steam.protobufs.steammessages_webui_friends_pb2',
    'SteamTV':                   'steam.protobufs.steammessages_webui_friends_pb2',
    'VoiceChat':                 'steam.protobufs.steammessages_webui_friends_pb2',
    'VoiceChatClient':           'steam.protobufs.steammessages_webui_friends_pb2',
    'WebRTCClient':              'steam.protobufs.steammessages_webui_friends_pb2',
    'WebRTCClientNotifications': 'steam.protobufs.steammessages_webui_friends_pb2',
}

method_lookup = {}


def get_um(method_name, response=False):
    """Get protobuf for given method name

    :param method_name: full method name (e.g. ``Player.GetGameBadgeLevels#1``)
    :type method_name: :class:`str`
    :param response: whether to return proto for response or request
    :type response: :class:`bool`
    :return: protobuf message
    """
    key = (method_name, response)

    if key not in method_lookup:
        match = re.findall(r'^([a-z]+)\.([a-z]+)#(\d)?$', method_name, re.I)
        if not match:
            return None

        interface, method, version = match[0]

        if interface not in service_lookup:
            return None

        package = import_module(service_lookup[interface])

        service = getattr(package, interface, None)
        if service is None:
            return None

        for method_desc in service.GetDescriptor().methods:
            name = "%s.%s#%d" % (interface, method_desc.name, 1)

            method_lookup[(name, False)] = getattr(package, method_desc.input_type.full_name, None)
            method_lookup[(name, True)] = getattr(package, method_desc.output_type.full_name, None)

    return method_lookup[key]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_store.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_store.proto',
  package='',
  syntax='proto2',
  serialized_options=_b('\220\001\001'),
  serialized_pb=_b('\n\x19steammessages_store.proto\x1a steammessages_unified_base.proto\"J\n&CStore_GetLocalizedNameForTags_Request\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0e\n\x06tagids\x18\x02 \x03(\r\"\x9f\x01\n\'CStore_GetLocalizedNameForTags_Response\x12:\n\x04tags\x18\x01 \x03(\x0b\x32,.CStore_GetLocalizedNameForTags_Response.Tag\x1a\x38\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x14\n\x0c\x65nglish_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"$\n\"CStore_GetStorePreferences_Request\"\xb1\x03\n\x16\x43Store_UserPreferences\x12\x18\n\x10primary_language\x18\x01 \x01(\r\x12\x1b\n\x13secondary_languages\x18\x02 \x01(\r\x12\x18\n\x10platform_windows\x18\x03 \x01(\x08\x12\x14\n\x0cplatform_mac\x18\x04 \x01(\x08\x12\x16\n\x0eplatform_linux\x18\x05 \x01(\x08\x12#\n\x1bhide_adult_content_violence\x18\x06 \x01(\x08\x12\x1e\n\x16hide_adult_content_sex\x18\x07 \x01(\x08\x12\x19\n\x11timestamp_updated\x18\x08 \x01(\r\x12\x1c\n\x14hide_store_broadcast\x18\t \x01(\x08\x12`\n\x17review_score_preference\x18\n \x01(\x0e\x32\x1b.EUserReviewScorePreference:\"k_EUserReviewScorePreference_Unset\x12\x38\n0timestamp_content_descriptor_preferences_updated\x18\x0b \x01(\x05\"\x91\x01\n\x19\x43Store_UserTagPreferences\x12\x37\n\x0ftags_to_exclude\x18\x01 \x03(\x0b\x32\x1e.CStore_UserTagPreferences.Tag\x1a;\n\x03Tag\x12\r\n\x05tagid\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0ftimestamp_added\x18\x03 \x01(\r\"\xd9\x01\n\'CStore_UserContentDescriptorPreferences\x12\x62\n\x1e\x63ontent_descriptors_to_exclude\x18\x01 \x03(\x0b\x32:.CStore_UserContentDescriptorPreferences.ContentDescriptor\x1aJ\n\x11\x43ontentDescriptor\x12\x1c\n\x14\x63ontent_descriptorid\x18\x01 \x01(\r\x12\x17\n\x0ftimestamp_added\x18\x02 \x01(\r\"\xda\x01\n#CStore_GetStorePreferences_Response\x12,\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x17.CStore_UserPreferences\x12\x33\n\x0ftag_preferences\x18\x02 \x01(\x0b\x32\x1a.CStore_UserTagPreferences\x12P\n\x1e\x63ontent_descriptor_preferences\x18\x03 \x01(\x0b\x32(.CStore_UserContentDescriptorPreferences\"\xe2\x01\n+CStore_StorePreferencesChanged_Notification\x12,\n\x0bpreferences\x18\x01 \x01(\x0b\x32\x17.CStore_UserPreferences\x12\x33\n\x0ftag_preferences\x18\x02 \x01(\x0b\x32\x1a.CStore_UserTagPreferences\x12P\n\x1e\x63ontent_descriptor_preferences\x18\x03 \x01(\x0b\x32(.CStore_UserContentDescriptorPreferences*\xa0\x01\n\x1a\x45UserReviewScorePreference\x12&\n\"k_EUserReviewScorePreference_Unset\x10\x00\x12+\n\'k_EUserReviewScorePreference_IncludeAll\x10\x01\x12-\n)k_EUserReviewScorePreference_ExcludeBombs\x10\x02\x32\xf9\x02\n\x05Store\x12\x98\x01\n\x17GetLocalizedNameForTags\x12\'.CStore_GetLocalizedNameForTags_Request\x1a(.CStore_GetLocalizedNameForTags_Response\"*\x82\xb5\x18&Gets tag names in a different language\x12\xaf\x01\n\x13GetStorePreferences\x12#.CStore_GetStorePreferences_Request\x1a$.CStore_GetStorePreferences_Response\"M\x82\xb5\x18IReturns the desired ratings board and maximum rating to show on the store\x1a#\x82\xb5\x18\x1f\x41 service to access store data.2\xee\x01\n\x0bStoreClient\x12\xb1\x01\n\x1dNotifyStorePreferencesChanged\x12,.CStore_StorePreferencesChanged_Notification\x1a\x0b.NoResponse\"U\x82\xb5\x18QNotification from server to client that the user\'s store preferences have changed\x1a+\x82\xb5\x18#Steam store to client notifications\xc0\xb5\x18\x02\x42\x03\x90\x01\x01')
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,])

_EUSERREVIEWSCOREPREFERENCE = _descriptor.EnumDescriptor(
  name='EUserReviewScorePreference',
  full_name='EUserReviewScorePreference',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScorePreference_Unset', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScorePreference_IncludeAll', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EUserReviewScorePreference_ExcludeBombs', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1594,
  serialized_end=1754,
)
_sym_db.RegisterEnumDescriptor(_EUSERREVIEWSCOREPREFERENCE)

EUserReviewScorePreference = enum_type_wrapper.EnumTypeWrapper(_EUSERREVIEWSCOREPREFERENCE)
k_EUserReviewScorePreference_Unset = 0
k_EUserReviewScorePreference_IncludeAll = 1
k_EUserReviewScorePreference_ExcludeBombs = 2



_CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST = _descriptor.Descriptor(
  name='CStore_GetLocalizedNameForTags_Request',
  full_name='CStore_GetLocalizedNameForTags_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='CStore_GetLocalizedNameForTags_Request.language', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tagids', full_name='CStore_GetLocalizedNameForTags_Request.tagids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=137,
)


_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='CStore_GetLocalizedNameForTags_Response.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tagid', full_name='CStore_GetLocalizedNameForTags_Response.Tag.tagid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='english_name', full_name='CStore_GetLocalizedNameForTags_Response.Tag.english_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CStore_GetLocalizedNameForTags_Response.Tag.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=299,
)

_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetLocalizedNameForTags_Response',
  full_name='CStore_GetLocalizedNameForTags_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='CStore_GetLocalizedNameForTags_Response.tags', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=299,
)


_CSTORE_GETSTOREPREFERENCES_REQUEST = _descriptor.Descriptor(
  name='CStore_GetStorePreferences_Request',
  full_name='CStore_GetStorePreferences_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=337,
)


_CSTORE_USERPREFERENCES = _descriptor.Descriptor(
  name='CStore_UserPreferences',
  full_name='CStore_UserPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary_language', full_name='CStore_UserPreferences.primary_language', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondary_languages', full_name='CStore_UserPreferences.secondary_languages', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_windows', full_name='CStore_UserPreferences.platform_windows', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_mac', full_name='CStore_UserPreferences.platform_mac', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_linux', full_name='CStore_UserPreferences.platform_linux', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_adult_content_violence', full_name='CStore_UserPreferences.hide_adult_content_violence', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_adult_content_sex', full_name='CStore_UserPreferences.hide_adult_content_sex', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_updated', full_name='CStore_UserPreferences.timestamp_updated', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hide_store_broadcast', full_name='CStore_UserPreferences.hide_store_broadcast', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='review_score_preference', full_name='CStore_UserPreferences.review_score_preference', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_content_descriptor_preferences_updated', full_name='CStore_UserPreferences.timestamp_content_descriptor_preferences_updated', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=773,
)


_CSTORE_USERTAGPREFERENCES_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='CStore_UserTagPreferences.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tagid', full_name='CStore_UserTagPreferences.Tag.tagid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='CStore_UserTagPreferences.Tag.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_added', full_name='CStore_UserTagPreferences.Tag.timestamp_added', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=921,
)

_CSTORE_USERTAGPREFERENCES = _descriptor.Descriptor(
  name='CStore_UserTagPreferences',
  full_name='CStore_UserTagPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags_to_exclude', full_name='CStore_UserTagPreferences.tags_to_exclude', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_USERTAGPREFERENCES_TAG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=921,
)


_CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR = _descriptor.Descriptor(
  name='ContentDescriptor',
  full_name='CStore_UserContentDescriptorPreferences.ContentDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_descriptorid', full_name='CStore_UserContentDescriptorPreferences.ContentDescriptor.content_descriptorid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp_added', full_name='CStore_UserContentDescriptorPreferences.ContentDescriptor.timestamp_added', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1067,
  serialized_end=1141,
)

_CSTORE_USERCONTENTDESCRIPTORPREFERENCES = _descriptor.Descriptor(
  name='CStore_UserContentDescriptorPreferences',
  full_name='CStore_UserContentDescriptorPreferences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content_descriptors_to_exclude', full_name='CStore_UserContentDescriptorPreferences.content_descriptors_to_exclude', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1141,
)


_CSTORE_GETSTOREPREFERENCES_RESPONSE = _descriptor.Descriptor(
  name='CStore_GetStorePreferences_Response',
  full_name='CStore_GetStorePreferences_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CStore_GetStorePreferences_Response.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_preferences', full_name='CStore_GetStorePreferences_Response.tag_preferences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_descriptor_preferences', full_name='CStore_GetStorePreferences_Response.content_descriptor_preferences', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1144,
  serialized_end=1362,
)


_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION = _descriptor.Descriptor(
  name='CStore_StorePreferencesChanged_Notification',
  full_name='CStore_StorePreferencesChanged_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferences', full_name='CStore_StorePreferencesChanged_Notification.preferences', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_preferences', full_name='CStore_StorePreferencesChanged_Notification.tag_preferences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_descriptor_preferences', full_name='CStore_StorePreferencesChanged_Notification.content_descriptor_preferences', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1365,
  serialized_end=1591,
)

_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG.containing_type = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE
_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE.fields_by_name['tags'].message_type = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG
_CSTORE_USERPREFERENCES.fields_by_name['review_score_preference'].enum_type = _EUSERREVIEWSCOREPREFERENCE
_CSTORE_USERTAGPREFERENCES_TAG.containing_type = _CSTORE_USERTAGPREFERENCES
_CSTORE_USERTAGPREFERENCES.fields_by_name['tags_to_exclude'].message_type = _CSTORE_USERTAGPREFERENCES_TAG
_CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR.containing_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
_CSTORE_USERCONTENTDESCRIPTORPREFERENCES.fields_by_name['content_descriptors_to_exclude'].message_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR
_CSTORE_GETSTOREPREFERENCES_RESPONSE.fields_by_name['preferences'].message_type = _CSTORE_USERPREFERENCES
_CSTORE_GETSTOREPREFERENCES_RESPONSE.fields_by_name['tag_preferences'].message_type = _CSTORE_USERTAGPREFERENCES
_CSTORE_GETSTOREPREFERENCES_RESPONSE.fields_by_name['content_descriptor_preferences'].message_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION.fields_by_name['preferences'].message_type = _CSTORE_USERPREFERENCES
_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION.fields_by_name['tag_preferences'].message_type = _CSTORE_USERTAGPREFERENCES
_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION.fields_by_name['content_descriptor_preferences'].message_type = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_GetLocalizedNameForTags_Request'] = _CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST
DESCRIPTOR.message_types_by_name['CStore_GetLocalizedNameForTags_Response'] = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_GetStorePreferences_Request'] = _CSTORE_GETSTOREPREFERENCES_REQUEST
DESCRIPTOR.message_types_by_name['CStore_UserPreferences'] = _CSTORE_USERPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_UserTagPreferences'] = _CSTORE_USERTAGPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_UserContentDescriptorPreferences'] = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES
DESCRIPTOR.message_types_by_name['CStore_GetStorePreferences_Response'] = _CSTORE_GETSTOREPREFERENCES_RESPONSE
DESCRIPTOR.message_types_by_name['CStore_StorePreferencesChanged_Notification'] = _CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION
DESCRIPTOR.enum_types_by_name['EUserReviewScorePreference'] = _EUSERREVIEWSCOREPREFERENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CStore_GetLocalizedNameForTags_Request = _reflection.GeneratedProtocolMessageType('CStore_GetLocalizedNameForTags_Request', (_message.Message,), dict(
  DESCRIPTOR = _CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetLocalizedNameForTags_Request)
  ))
_sym_db.RegisterMessage(CStore_GetLocalizedNameForTags_Request)

CStore_GetLocalizedNameForTags_Response = _reflection.GeneratedProtocolMessageType('CStore_GetLocalizedNameForTags_Response', (_message.Message,), dict(

  Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), dict(
    DESCRIPTOR = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE_TAG,
    __module__ = 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_GetLocalizedNameForTags_Response.Tag)
    ))
  ,
  DESCRIPTOR = _CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetLocalizedNameForTags_Response)
  ))
_sym_db.RegisterMessage(CStore_GetLocalizedNameForTags_Response)
_sym_db.RegisterMessage(CStore_GetLocalizedNameForTags_Response.Tag)

CStore_GetStorePreferences_Request = _reflection.GeneratedProtocolMessageType('CStore_GetStorePreferences_Request', (_message.Message,), dict(
  DESCRIPTOR = _CSTORE_GETSTOREPREFERENCES_REQUEST,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetStorePreferences_Request)
  ))
_sym_db.RegisterMessage(CStore_GetStorePreferences_Request)

CStore_UserPreferences = _reflection.GeneratedProtocolMessageType('CStore_UserPreferences', (_message.Message,), dict(
  DESCRIPTOR = _CSTORE_USERPREFERENCES,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_UserPreferences)
  ))
_sym_db.RegisterMessage(CStore_UserPreferences)

CStore_UserTagPreferences = _reflection.GeneratedProtocolMessageType('CStore_UserTagPreferences', (_message.Message,), dict(

  Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), dict(
    DESCRIPTOR = _CSTORE_USERTAGPREFERENCES_TAG,
    __module__ = 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_UserTagPreferences.Tag)
    ))
  ,
  DESCRIPTOR = _CSTORE_USERTAGPREFERENCES,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_UserTagPreferences)
  ))
_sym_db.RegisterMessage(CStore_UserTagPreferences)
_sym_db.RegisterMessage(CStore_UserTagPreferences.Tag)

CStore_UserContentDescriptorPreferences = _reflection.GeneratedProtocolMessageType('CStore_UserContentDescriptorPreferences', (_message.Message,), dict(

  ContentDescriptor = _reflection.GeneratedProtocolMessageType('ContentDescriptor', (_message.Message,), dict(
    DESCRIPTOR = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES_CONTENTDESCRIPTOR,
    __module__ = 'steammessages_store_pb2'
    # @@protoc_insertion_point(class_scope:CStore_UserContentDescriptorPreferences.ContentDescriptor)
    ))
  ,
  DESCRIPTOR = _CSTORE_USERCONTENTDESCRIPTORPREFERENCES,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_UserContentDescriptorPreferences)
  ))
_sym_db.RegisterMessage(CStore_UserContentDescriptorPreferences)
_sym_db.RegisterMessage(CStore_UserContentDescriptorPreferences.ContentDescriptor)

CStore_GetStorePreferences_Response = _reflection.GeneratedProtocolMessageType('CStore_GetStorePreferences_Response', (_message.Message,), dict(
  DESCRIPTOR = _CSTORE_GETSTOREPREFERENCES_RESPONSE,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_GetStorePreferences_Response)
  ))
_sym_db.RegisterMessage(CStore_GetStorePreferences_Response)

CStore_StorePreferencesChanged_Notification = _reflection.GeneratedProtocolMessageType('CStore_StorePreferencesChanged_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION,
  __module__ = 'steammessages_store_pb2'
  # @@protoc_insertion_point(class_scope:CStore_StorePreferencesChanged_Notification)
  ))
_sym_db.RegisterMessage(CStore_StorePreferencesChanged_Notification)


DESCRIPTOR._options = None

_STORE = _descriptor.ServiceDescriptor(
  name='Store',
  full_name='Store',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\202\265\030\037A service to access store data.'),
  serialized_start=1757,
  serialized_end=2134,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetLocalizedNameForTags',
    full_name='Store.GetLocalizedNameForTags',
    index=0,
    containing_service=None,
    input_type=_CSTORE_GETLOCALIZEDNAMEFORTAGS_REQUEST,
    output_type=_CSTORE_GETLOCALIZEDNAMEFORTAGS_RESPONSE,
    serialized_options=_b('\202\265\030&Gets tag names in a different language'),
  ),
  _descriptor.MethodDescriptor(
    name='GetStorePreferences',
    full_name='Store.GetStorePreferences',
    index=1,
    containing_service=None,
    input_type=_CSTORE_GETSTOREPREFERENCES_REQUEST,
    output_type=_CSTORE_GETSTOREPREFERENCES_RESPONSE,
    serialized_options=_b('\202\265\030IReturns the desired ratings board and maximum rating to show on the store'),
  ),
])
_sym_db.RegisterServiceDescriptor(_STORE)

DESCRIPTOR.services_by_name['Store'] = _STORE


_STORECLIENT = _descriptor.ServiceDescriptor(
  name='StoreClient',
  full_name='StoreClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=_b('\202\265\030#Steam store to client notifications\300\265\030\002'),
  serialized_start=2137,
  serialized_end=2375,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyStorePreferencesChanged',
    full_name='StoreClient.NotifyStorePreferencesChanged',
    index=0,
    containing_service=None,
    input_type=_CSTORE_STOREPREFERENCESCHANGED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=_b('\202\265\030QNotification from server to client that the user\'s store preferences have changed'),
  ),
])
_sym_db.RegisterServiceDescriptor(_STORECLIENT)

DESCRIPTOR.services_by_name['StoreClient'] = _STORECLIENT

Store = service_reflection.GeneratedServiceType('Store', (_service.Service,), dict(
  DESCRIPTOR = _STORE,
  __module__ = 'steammessages_store_pb2'
  ))

Store_Stub = service_reflection.GeneratedServiceStubType('Store_Stub', (Store,), dict(
  DESCRIPTOR = _STORE,
  __module__ = 'steammessages_store_pb2'
  ))


StoreClient = service_reflection.GeneratedServiceType('StoreClient', (_service.Service,), dict(
  DESCRIPTOR = _STORECLIENT,
  __module__ = 'steammessages_store_pb2'
  ))

StoreClient_Stub = service_reflection.GeneratedServiceStubType('StoreClient_Stub', (StoreClient,), dict(
  DESCRIPTOR = _STORECLIENT,
  __module__ = 'steammessages_store_pb2'
  ))


# @@protoc_insertion_point(module_scope)
